/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { FluidObject } from "@fluidframework/core-interfaces";
import { IFluidHandleContext, type IFluidHandleInternal } from "@fluidframework/core-interfaces/internal";
import { FluidHandleBase } from "@fluidframework/runtime-utils/internal";
/**
 * This handle is used to dynamically load a Fluid object on a remote client and is created on parsing a serialized
 * FluidObjectHandle.
 * This class is used to generate an IFluidHandle when de-serializing any all handles (including handles to DDSes,
 * custom objects) that are stored in SharedObjects. The Data Store or SharedObject corresponding to the
 * IFluidHandle can be retrieved by calling `get` on it.
 */
export declare class RemoteFluidObjectHandle extends FluidHandleBase<FluidObject> {
    readonly absolutePath: string;
    readonly routeContext: IFluidHandleContext;
    readonly isAttached = true;
    private objectP;
    /**
     * Creates a new RemoteFluidObjectHandle when parsing an IFluidHandle.
     * @param absolutePath - The absolute path to the handle from the container runtime.
     * @param routeContext - The root IFluidHandleContext that has a route to this handle.
     */
    constructor(absolutePath: string, routeContext: IFluidHandleContext);
    get(): Promise<FluidObject>;
    attachGraph(): void;
    bind(handle: IFluidHandleInternal): void;
}
//# sourceMappingURL=remoteObjectHandle.d.ts.map