"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoteFluidObjectHandle = void 0;
const internal_1 = require("@fluidframework/container-runtime/internal");
const internal_2 = require("@fluidframework/core-utils/internal");
const internal_3 = require("@fluidframework/runtime-utils/internal");
/**
 * This handle is used to dynamically load a Fluid object on a remote client and is created on parsing a serialized
 * FluidObjectHandle.
 * This class is used to generate an IFluidHandle when de-serializing any all handles (including handles to DDSes,
 * custom objects) that are stored in SharedObjects. The Data Store or SharedObject corresponding to the
 * IFluidHandle can be retrieved by calling `get` on it.
 */
class RemoteFluidObjectHandle extends internal_3.FluidHandleBase {
    /**
     * Creates a new RemoteFluidObjectHandle when parsing an IFluidHandle.
     * @param absolutePath - The absolute path to the handle from the container runtime.
     * @param routeContext - The root IFluidHandleContext that has a route to this handle.
     */
    constructor(absolutePath, routeContext) {
        super();
        this.absolutePath = absolutePath;
        this.routeContext = routeContext;
        this.isAttached = true;
        (0, internal_2.assert)(absolutePath.startsWith("/"), 0x19d /* "Handles should always have absolute paths" */);
    }
    async get() {
        if (this.objectP === undefined) {
            // Add `viaHandle` header to distinguish from requests from non-handle paths.
            const request = {
                url: this.absolutePath,
                headers: { [internal_1.RuntimeHeaders.viaHandle]: true },
            };
            this.objectP = this.routeContext.resolveHandle(request).then((response) => {
                if (response.mimeType === "fluid/object") {
                    const fluidObject = response.value;
                    return fluidObject;
                }
                throw (0, internal_3.responseToException)(response, request);
            });
        }
        return this.objectP;
    }
    attachGraph() {
        return;
    }
    bind(handle) {
        handle.attachGraph();
    }
}
exports.RemoteFluidObjectHandle = RemoteFluidObjectHandle;
//# sourceMappingURL=remoteObjectHandle.js.map